# rjfrank

🎉 An honorary Python module celebrating Randy Frank's legendary contributions.

This playful module includes memorable quotes, fun attributes, and a stylish farewell message when removed from runtime.

---

## Install

```bash
pip install rjfrank
```

## Usage

```bash
>> import rjfrank
>> dir(rjfrank)
>> rjfrank.catan_negotiations()
>> rjfrank.movie_quotes()
>> rjfrank.retire()
>> rjfrank.ode()
>> del rjfrank
```

---

## License

MIT License

---

## Credits

This project was inspired by an idea from **David Bremer** to honor **Randy Frank**.

![initial_idea.png](randy.png)
